@@ -6,7 +6,7 @@ use Gnuplot::Builder::Script;
 use Gnuplot::Builder::Dataset;
 use Gnuplot::Builder::Process;
 
-our $VERSION = "0.28";
+our $VERSION = "0.29";
 
 our @EXPORT = our @EXPORT_OK = qw(gscript gfunc gfile gdata ghelp gwait);
 
@@ -315,6 +315,16 @@ if you do not have CPAN RT account.
  
 Toshio Ito, C<< <toshioito at cpan.org> >>
 
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Moritz Grosch (LittleFox)
+
+=back
+
 
 =head1 LICENSE AND COPYRIGHT
 
