@@ -245,11 +245,12 @@ sub _draw_with {
         _write_inline_data($writer, $dataset_objects);
     };
     my @commands = ($plotter);
-    _wrap_commands_with_output(\@commands, $args{output});
     return $self->run_with(
         do => \@commands,
         writer => $args{writer},
-        async => $args{async}
+        async => $args{async},
+        output => $args{output},
+        no_stderr => $args{no_stderr}
     );
 }
 
@@ -291,11 +292,12 @@ sub multiplot_with {
         (defined($args{option}) && $args{option} ne "")
             ? "set multiplot $args{option}" : "set multiplot";
     my @commands = ($multiplot_command, $wrapped_do, "unset multiplot");
-    _wrap_commands_with_output(\@commands, $args{output});
     return $self->run_with(
         do => \@commands,
         writer => $args{writer},
-        async => $args{async}
+        async => $args{async},
+        output => $args{output},
+        no_stderr => $args{no_stderr}
     );
 }
 
@@ -320,7 +322,7 @@ sub run_with {
     }elsif(ref($commands) ne "ARRAY") {
         $commands = [$commands];
     }
-    my $async = $args{async};
+    _wrap_commands_with_output($commands, $args{output});
     my $do = sub {
         my $writer = shift;
         (!defined($_context_writer) || refaddr($_context_writer) != refaddr($writer))
@@ -337,13 +339,14 @@ sub run_with {
             }
         }
     };
+
     my $result = "";
     if(defined($args{writer})) {
         $do->($args{writer});
     }elsif(defined($_context_writer)) {
         $do->($_context_writer);
     }else {
-        $result = Gnuplot::Builder::Process->with_new_process(async => $async, do => $do);
+        $result = Gnuplot::Builder::Process->with_new_process(async => $args{async}, do => $do, no_stderr => $args{no_stderr});
     }
     return $result;
 }
@@ -428,7 +431,6 @@ Most object methods return the object itself, so that you can chain those method
 
 Build and return the gnuplot script string.
 
-
 =head2 $builder = $buider->add($sentence, ...)
 
 Add gnuplot script sentences to the C<$builder>.
@@ -765,7 +767,7 @@ This method lets a gnuplot process do the actual job.
 
 You can specify more than one C<$dataset>s to plot.
 
-The return value C<$result> is the data that the gnuplot process writes to STDOUT and STDERR.
+The return value C<$result> is the data that the gnuplot process writes to STDOUT and STDERR (by default).
 
 Usually you should use a L<Gnuplot::Builder::Dataset> object for C<$dataset>.
 In this case, you can skip the rest of this section.
@@ -848,6 +850,14 @@ After "plot" command, it prints "set output" command with no argument to unlock
 
 If not set, it won't print "set output" commands.
 
+=item C<no_stderr> => BOOL (optional, default: C<$Gnuplot::Builder::Process::NO_STDERR>)
+
+If set to true, the return value C<$result> contains gnuplot's STDOUT only. It doesn't contain STDERR.
+If false, C<$result> contains both STDOUT and STDERR.
+This option has no effect if C<writer> or C<async> is set.
+
+By default, it's false. You can change the default by C<$Gnuplot::Builder::Process::NO_STDERR> package varible.
+
 =item C<writer> => CODE-REF (optional)
 
 A code-ref to receive the whole script string instead of the gnuplot process.
@@ -912,7 +922,7 @@ The C<$code> is called like
 
 where C<$writer> is a code-ref that you can call to write any data to the gnuplot process.
 
-The return value C<$result> is the data that the gnuplot process writes to STDOUT and STDERR.
+The return value C<$result> is the data that the gnuplot process writes to STDOUT and STDERR (by default).
 
 The script written to the C<$writer> is enclosed by "set multiplot" and "unset multiplot" commands,
 and passed to the gnuplot process.
@@ -957,25 +967,31 @@ A code-ref that is executed in the multiplot context.
 
 An option string for "set multiplot" command.
 
+=item C<no_stderr> => BOOL (optional, default: C<$Gnuplot::Builder::Process::NO_STDERR>)
+
+If set to true, the return value C<$result> contains STDOUT only. It doesn't contain gnuplot's STDERR.
+
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
+
 =item C<output> => OUTPUT_FILENAME (optional)
 
 If set, "set output" command is printed just before "set multiplot" command.
 
-See C<plot_with()> method for detail.
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
 
 =item C<writer> => CODE-REF (optional)
 
 A code-ref to receive the whole script string.
 If set, the return value C<$result> will be an empty string.
 
-See C<plot_with()> method for detail.
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
 
 =item C<async> => BOOL (optional, default: C<$Gnuplot::Builder::Process::ASYNC>)
 
 If set to true, it won't wait for the gnuplot process to finish.
 In this case, the return value C<$result> will be an empty string.
 
-See C<plot_with()> method for detail.
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
 
 =back
 
@@ -1035,7 +1051,7 @@ where C<$writer> is a code-ref that you can call to write any data to the gnuplo
 
 =back
 
-The return value C<$result> is the data that the gnuplot process writes to STDOUT and STDERR.
+The return value C<$result> is the data that the gnuplot process writes to STDOUT and STDERR (by default).
 
 C<run()> method is useful when you want to execute "plot" command more than once in a single gnuplot process.
 For example,
@@ -1102,17 +1118,29 @@ Run the script with more functionalities than C<run()> method.
 A command or an array-ref of commands to be executed.
 See C<run()> for specification of commands.
 
+=item C<output> => OUTPUT_FILENAME (optional)
+
+If set, "set output" command is printed just before running commands.
+
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
+
+=item C<no_stderr> => BOOL (optional, default: C<$Gnuplot::Builder::Process::NO_STDERR>)
+
+If set to true, the return value C<$result> contains STDOUT only. It doesn't contain gnuplot's STDERR.
+
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
+
 =item C<writer> => CODE-REF (optional)
 
 A code-ref to receive the whole script string. If set, the return value C<$result> will be an empty string.
 
-See C<plot_with()> method for detail.
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
 
 =item C<async> => BOOL (optional, default: C<$Gnuplot::Builder::Process::ASYNC>)
 
 If set to true, it won't wait for the gnuplot process to finish. In this case, the return value C<$result> will be an empty string.
 
-See C<plot_with()> method for detail.
+See L<< C<plot_with()>|"$result = $builder->plot_with(%args)" >> method for detail.
 
 =back
 
